==> BiocMetaWorkflow_1.0.0.tar.gz: BiocMetaWorkflow/inst/doc/Authoring_BioC_Workflows.R <==
## ----global_options, include=FALSE-----------------------------------------
knitr::opts_chunk$set(fig.pos = 'h')
doc_dir <- getwd()
## run all code in a temporary directory
knitr::opts_knit$set(root.dir = tempdir())

## ----packageInstallation, eval = FALSE-------------------------------------
#  source("http://www.bioconductor.org/biocLite.R")
#  biocLite("BiocWorkflowTools")

## ----createBiocWorkflow, message=FALSE-------------------------------------
BiocWorkflowTools::createBiocWorkflow("MyWorkflow",
                                      quiet = TRUE,
                                      open = FALSE)

## ----RStudioNew, echo = FALSE, out.width='50%', fig.align='center', fig.cap="Creation of a new article is integrated into RStudio.  The F1000Research template can be accessed via the `New R Markdown' file menu dialog"----
knitr::include_graphics("figures/Rstudio_newdoc.png")

## ----createDraft-----------------------------------------------------------
rmd_file <- rmarkdown::draft("MyArticle.Rmd",
                             template = "f1000_article",
                             package = "BiocWorkflowTools",
                             edit = FALSE)

## ----render, eval = FALSE--------------------------------------------------
#  rmarkdown::render(rmd_file)

## ----renderquiet, include = FALSE------------------------------------------
rmarkdown::render(rmd_file, quiet=TRUE)

## ----uploadToOverleaf, eval=FALSE------------------------------------------
#  BiocWorkflowTools::uploadToOverleaf("MyArticle")

==> BiocMetaWorkflow_1.2.0.tar.gz: BiocMetaWorkflow/inst/doc/Authoring_BioC_Workflows.R <==
## ----global_options, include=FALSE-----------------------------------------
knitr::opts_chunk$set(fig.pos = 'h')
doc_dir <- getwd()
## run all code in a temporary directory
knitr::opts_knit$set(root.dir = tempdir())

## ----packageInstallation, eval = FALSE-------------------------------------
#  if (!"BiocManager" %in% rownames(installed.packages()))
#       install.packages("BiocManager")
#  BiocManager::install("BiocWorkflowTools")

## ----createBiocWorkflow, message=FALSE-------------------------------------
BiocWorkflowTools::createBiocWorkflow("MyWorkflow",
                                      quiet = TRUE,
                                      open = FALSE)

## ----RStudioNew, echo = FALSE, out.width='50%', fig.align='center', fig.cap="Creation of a new article is integrated into RStudio.  The F1000Research template can be accessed via the `New R Markdown' file menu dialog"----
knitr::include_graphics("figures/Rstudio_newdoc.png")

## ----createDraft-----------------------------------------------------------
rmd_file <- rmarkdown::draft("MyArticle.Rmd",
                             template = "f1000_article",
                             package = "BiocWorkflowTools",
                             edit = FALSE)

## ----render, eval = FALSE--------------------------------------------------
#  rmarkdown::render(rmd_file)

## ----renderquiet, include = FALSE------------------------------------------
rmarkdown::render(rmd_file, quiet=TRUE)

## ----uploadToOverleaf, eval=FALSE------------------------------------------
#  BiocWorkflowTools::uploadToOverleaf("MyArticle")
